@@ -39,6 +39,7 @@ public class PulsarMessage<T> {
 
     @Nullable private final byte[] orderingKey;
     @Nullable private final String key;
+    private final boolean isBase64EncodedKey;
     private final long eventTime;
     @Nullable private final Schema<T> schema;
     @Nullable private final T value;
@@ -57,6 +58,7 @@ public class PulsarMessage<T> {
     PulsarMessage(
             @Nullable byte[] orderingKey,
             @Nullable String key,
+            boolean isBase64EncodedKey,
             long eventTime,
             @Nullable Schema<T> schema,
             @Nullable T value,
@@ -66,6 +68,7 @@ public class PulsarMessage<T> {
             boolean disableReplication) {
         this.orderingKey = orderingKey;
         this.key = key;
+        this.isBase64EncodedKey = isBase64EncodedKey;
         this.eventTime = eventTime;
         this.schema = schema;
         this.value = value;
@@ -117,6 +120,10 @@ public class PulsarMessage<T> {
         return key;
     }
 
+    public boolean isBase64EncodedKey() {
+        return isBase64EncodedKey;
+    }
+
     public long getEventTime() {
         return eventTime;
     }
