@@ -31,9 +31,6 @@ class PulsarSourceBuilderTest {
         PulsarSourceBuilder<String> builder = new PulsarSourceBuilder<>();
         fillRequiredFields(builder);
 
-        assertThatThrownBy(() -> builder.setAdminUrl("admin-url2"))
-                .isInstanceOf(IllegalArgumentException.class);
-
         assertThatThrownBy(() -> builder.setServiceUrl("service-url2"))
                 .isInstanceOf(IllegalArgumentException.class);
 
@@ -50,7 +47,6 @@ class PulsarSourceBuilderTest {
     }
 
     private void fillRequiredFields(PulsarSourceBuilder<String> builder) {
-        builder.setAdminUrl("admin-url");
         builder.setServiceUrl("service-url");
         builder.setSubscriptionName("subscription-name");
         builder.setTopics("topic");
