@@ -59,7 +59,6 @@ import static java.util.concurrent.TimeUnit.MILLISECONDS;
 import static java.util.stream.Collectors.toList;
 import static org.apache.commons.lang3.RandomStringUtils.randomAlphanumeric;
 import static org.apache.flink.connector.base.DeliveryGuarantee.EXACTLY_ONCE;
-import static org.apache.flink.connector.pulsar.common.config.PulsarOptions.PULSAR_ADMIN_URL;
 import static org.apache.flink.connector.pulsar.common.config.PulsarOptions.PULSAR_ENABLE_TRANSACTION;
 import static org.apache.flink.connector.pulsar.common.config.PulsarOptions.PULSAR_SERVICE_URL;
 import static org.apache.flink.connector.pulsar.common.utils.PulsarTransactionUtils.getTcClient;
@@ -426,7 +425,6 @@ public class PulsarRuntimeOperator implements Closeable {
     public Configuration config() {
         Configuration configuration = new Configuration();
         configuration.set(PULSAR_SERVICE_URL, serviceUrl());
-        configuration.set(PULSAR_ADMIN_URL, adminUrl());
         return configuration;
     }
 
@@ -481,7 +479,7 @@ public class PulsarRuntimeOperator implements Closeable {
         }
     }
 
-    private <T> Producer<T> createProducer(String topic, Schema<T> schema) throws Exception {
+    public <T> Producer<T> createProducer(String topic, Schema<T> schema) throws Exception {
         return client().newProducer(schema)
                 .topic(topic)
                 .enableBatching(false)
@@ -490,7 +488,7 @@ public class PulsarRuntimeOperator implements Closeable {
                 .create();
     }
 
-    private <T> Consumer<T> createConsumer(String topic, Schema<T> schema) throws Exception {
+    public <T> Consumer<T> createConsumer(String topic, Schema<T> schema) throws Exception {
         // Create the earliest subscription if it's not existed.
         List<String> subscriptions = admin().topics().getSubscriptions(topic);
         if (!subscriptions.contains(SUBSCRIPTION_NAME)) {
